// Persistence of Vision Ray Tracer Scene Description File
// File: jldesert.pov
// Vers: 3.5
// Desc: The lighthouse keeper
// Date: 08/28/02
// Auth: Jochen Lippert
//
#version 3.5;
#include "colors.inc"

#local Test = off;

#local BodyHeight = 0.4;
#local NeckRadius = 0.035;
#local HeadRadius = 0.075;
#local UpperArmLength = 0.22;
#local LowerArmLength = 0.22;
#local LegLength = 0.5;

#local Body = superellipsoid
{
	<1, 0.4>
	rotate x * 90
	scale <0.12, BodyHeight / 2, 0.07>
	translate y * (LegLength + BodyHeight / 2)
}

#local Neck = cylinder
{
	<0, (LegLength + BodyHeight) - 0.05, 0>
	<0, LegLength + BodyHeight + 0.1, 0>
	NeckRadius
}

#local Head = superellipsoid
{
	<1, 0.8>
	rotate x * 90
	scale HeadRadius
	scale <0.7, 1, 1>
	scale <1, 1, 0.8>
	translate <0, LegLength + BodyHeight + HeadRadius, 0>
}

#local UpperArm = superellipsoid
{
	<1, 0.5>
	rotate x * 90
	scale <1, UpperArmLength / 2, 1>
	scale <0.03, 1, 0.03>
	translate y * UpperArmLength / 2
//	0, 0.03
//	UpperArmLength * y, 0.03
}

#local LowerArm = cone
{
	0, 0.025
	<0, LowerArmLength, 0>, 0.03
	translate y * -LowerArmLength
	rotate x * 90
	translate y * LowerArmLength
}

#local Leg = cone
{
	0, 0.04
	LegLength * y, 0.05
}

#declare Dude = union
{
	union
	{
		object
		{
			Body
			translate y * -(LegLength + BodyHeight)
			rotate x * -40
			translate y * (LegLength + BodyHeight)
			translate <0, -0.025, -0.005>
		}
		object
		{
			Neck
			translate y * -(LegLength + BodyHeight)
			rotate x * -20
			translate y * (LegLength + BodyHeight)
		}
		object
		{
			Head
			translate y * -(LegLength + BodyHeight)
			rotate x * -10
			translate y * (LegLength + BodyHeight)
			translate z * -0.01
		}
		
		// Right arm
		union
		{
			object
			{
				UpperArm
				rotate z * -12
				translate y * (((LegLength + BodyHeight) - UpperArmLength) - 0.01)
			}
			object
			{
				LowerArm
				rotate y * -90
				translate y * ((LegLength + BodyHeight) - (UpperArmLength + LowerArmLength))
				translate x * 0.01
			}
			translate x * -0.13
			translate y * -(((LegLength + BodyHeight) - UpperArmLength) - 0.01)
			rotate x * 20
			translate y * (((LegLength + BodyHeight) - UpperArmLength) - 0.01)
			translate z * -0.05
		}
		
		// Left arm
		union
		{
			object
			{
				UpperArm
				rotate z * 12
				translate y * (((LegLength + BodyHeight) - UpperArmLength) - 0.01)
			}
			object
			{
				LowerArm
				translate y * ((LegLength + BodyHeight) - (UpperArmLength + LowerArmLength))
				rotate y * 90
				translate x * -0.01
			}
			translate x * 0.13
			translate y * -(((LegLength + BodyHeight) - UpperArmLength) - 0.01)
			rotate x * 20
			translate y * (((LegLength + BodyHeight) - UpperArmLength) - 0.01)
			translate z * -0.05
		}
		// Shift body until it fits onto legs. :)
		translate y * -0.1
	}
	object
	{
		Leg
		translate x * -0.05
		translate z * 0.22
	}
	object
	{
		Leg
		translate x * 0.05
		translate z * 0.22
	}
}

#if (Test)
global_settings {
  assumed_gamma 1.0
}

// ----------------------------------------

camera {
  location  <0.0, 1.5, -4.0>
  direction 1.5*z
  right     x*image_width/image_height
  look_at   <0.0, 0.5,  0.0>
  angle 30
}

sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.7 rgb <0.0,0.1,0.8>]
    }
  }
}

light_source {
  <0, 0, 0>            // light's position (translated below)
  color rgb <1, 1, 1>  // light's color
  translate <-30, 30, -30>
}

// ----------------------------------------

plane {
  y, 0
  pigment { color rgb <0.7,0.5,0.3> }
}

object
{
	Dude
	pigment {color rgb 1}
	//rotate y * 90
	//rotate y * 107
}
#end
