// Persistence of Vision Ray Tracer Scene Description File
// File: landscap.inc
// Vers: 3.5
// Desc: Landscape for jldesert.pov
// Date: 08/28/02
// Auth: Jochen Lippert
//
#version 3.5;
#include "colors.inc"
#include "functions.inc"

#include "globals.inc"

#declare Test = off;

#declare SunPos = <-150, 66, 500>;

#declare Landscape = union
{
	union
	{
		// Desert
		isosurface
		{
			function
			{
				y
				+ f_noise3d(x * 3, y * 3, z * 3) * 0.25
			}
			threshold 0
			max_gradient 2
			contained_by {box {<-1000,-1,-1000>, < 1000, 1, 1000>}}
			texture {MySand}
			scale <30, 10, 10>
			rotate y * -30
		}
		
		// Mountains
		isosurface
		{
			function
			{
				y
				+ f_noise3d(x, y, z)
			}
			threshold 0
			max_gradient 2
			contained_by {box {<-0.8, -1, -2>, <0.5, 1, 2>}}
			texture {MyMountains}
			rotate y * -90
			scale <250, 50, 100>
			translate x * -50
			translate y * 28
			translate z * 500
		}
	    translate z * 600
	    rotate y * -8
	}
	
	// Sun
	union
	{
		sphere
		{
			0, 7
			pigment {color rgb 1}
			finish {ambient 1}
			no_shadow
		}
		
		// Halo
		disc
		{
			0, -z, 1
			pigment
			{
				spherical
				color_map
				{
					[0.0 color rgbf <1, 1, 1, 1.0>]
					[1.0 color rgbf <1, 1, 1, 0.1>]
				}
			}
			finish
			{
				ambient 1
				diffuse 0
			}
			no_shadow
			scale 20
		}
		translate SunPos
	}
}

#if (Test)
global_settings {
  assumed_gamma 1.0
}
// ----------------------------------------
camera {
  location  <0.0, 0.1, -4.0>
  direction 1.5*z
  right     x*image_width/image_height
  look_at   <0.0, 0.0,  0.0>
}
sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.7 rgb <0.0,0.1,0.8>]
    }
  }
}
light_source {
  <0, 0, 0>            // light's position (translated below)
  color rgb <1, 1, 1>  // light's color
  translate <-30, 30, -30>
}
// ----------------------------------------

object {Landscape}
#end
