// Persistence of Vision Ray Tracer Scene Description File
// File: lhtop.inc
// Vers: 3.5
// Desc: Lighthouse Top
// Date: 08/28/02
// Auth: Jochen Lippert
//
#version 3.5;

#include "globals.inc"

#local WindowFrame = box
{
	<-0.004, -0.05, -0.004>
	<0.004, 0.095, 0.004>
}

#local WindowStuff = union
{
  	PlaceObjectsAtCircle(WindowFrame, 0.096, 7)
}

#local RoofThing = cylinder
{
	0
	<0.012, 0.012, 0>, 0.001
	//<0.020, 0.020, 0>, 0.001
}

#local RoofStuff = union
{
	PlaceObjectsAtCircle(RoofThing, 0.148, 16)
	torus
	{
		0.148 + 0.012, 0.001
		translate y * 0.012
	}
	torus
	{
		0.148 + 0.008, 0.001
		translate y * 0.008
	}
	torus
	{
		0.148 + 0.004, 0.001
		translate y * 0.004
	}
}

#local Lamphouse = union
{
	// Bottom of lamp house
	cylinder
	{
		0,
		y * 0.1, 0.1
	}
	// "Windows"
	// This doesn't work somehow...
/*
	object
	{
		difference
		{
			// Outer
			cylinder
			{
				0,
				y * 0.08, 0.098
			}
			// Inner
			cylinder
			{
				y * -0.01,
				y * 0.09, 0.096
			}
		}
		texture {MyGlass}
		interior {I_Glass}
		no_shadow
		translate y * 0.1
  	}
*/
// This is better, but not quite what I want...
/*
	cylinder
	{
		0,
		y * 0.08, 0.098
		hollow
		no_shadow
		texture {MyGlass}
		translate y * 0.1
	}
*/	
	// "Window frames"
	object
	{
		WindowStuff
		//rotate y * -180
		translate y * 0.1
	}
	// Top of lamp house
	cylinder
	{
		0,
		0.03 * y, 0.1
		translate y * 0.18
	}
	texture {MyBlack}
}

// Macro for lens parts
#macro SphereSlice(Radius, MinY, MaxY)
	intersection
	{
		sphere {0, Radius}
		box {<-2 * Radius, MinY, -2 * Radius> <2 * Radius, MaxY, 2 * Radius>}
		translate y * -MinY
	}
#end

// Fresnel type lens
#local Lamp = difference
{
	merge
	{
		sphere
		{
			0, 1
		}
		#local i = 1;
		#while (i <= 7)
		object
		{
			SphereSlice(1.02 + i * 0.04, 0.22 + i * 0.11, 0.22 + i * 0.11 + 0.1)
			translate y * (0.22 + i * 0.11)
		}
		object
		{
			SphereSlice(1.02 + i * 0.04, 0.22 + i * 0.11, 0.22 + i * 0.11 + 0.1)
			rotate x * 180
			translate y * -(0.22 + i * 0.11)
		}
		#local i = i + 1;
		#end
	}
	cylinder
	{
		-1.1 * y
		1.1 * y, 0.7
	}
}

#local LampStuff = union
{
	// Lamp
	object
	{
		Lamp
		texture {MyLampGlass}
		interior {I_Glass}
		scale 0.03
		//translate y * 1.93
		translate y * 0.13
	}
  	// Colored glasses
  	union
  	{
  		union
  		{
  			box
  			{
  				<-0.015, 0, -0.001>
  				<0.015, 0.08, 0.001>
 				texture {MyGreenGlass}
				interior {I_Glass}
  			}
  			cylinder
  			{
  				<-0.015, 0.08, 0> + <0.001, -0.001, 0>,
  				<-0.015, 0.08, 0> + <-0.01, 0.01, 0>, 0.001
  				texture {MyBlack}
  			}
  			cylinder
  			{
  				<0.015, 0.08, 0> + <-0.001, -0.001, 0>,
  				<0.015, 0.08, 0> + <0.01, 0.01, 0>, 0.001
  				texture {MyBlack}
  			}
			translate z * -0.06
			translate y * 0.09
 			rotate y * -20
  		}
  		union
  		{
  			box
  			{
  				<-0.014, 0, -0.001>
  				<0.014, 0.08, 0.001>
 				texture {MyRedGlass}
				interior {I_Glass}
  			}
  			cylinder
  			{
  				<-0.015, 0.08, 0> + <0.001, -0.001, 0>,
  				<-0.015, 0.08, 0> + <-0.01, 0.01, 0>, 0.001
  				texture {MyBlack}
  			}
  			cylinder
  			{
  				<0.015, 0.08, 0> + <-0.001, -0.001, 0>,
  				<0.015, 0.08, 0> + <0.01, 0.01, 0>, 0.001
  				texture {MyBlack}
  			}
 			translate z * -0.06
			translate y * 0.09
			rotate y * 15
  		}
  		// Place at a nice position...
  		rotate y * 146
  	}
}

#local Roof = union
{
	// Real roof
	cone
	{
		0, 0.15,
		y * 0.1, 0
	}
	cylinder
	{
		y * -0.001,
		y * 0.001, 0.15
	}
	// Wires around border
	object
	{
		RoofStuff
	}
	// Staff
	union
	{
		cylinder
		{
			0,
			y * 0.004, 0.009
			translate y * -0.005
		}
		sphere
		{
			0, 0.01
			translate y * 0.005
		}
		cone
		{
			0, 0.003
			0.15 * y, 0.001
			translate y * -0.01
		}
		translate y * 0.1
	}
	// Wire stuff
	union
	{
		// Prepare some vector stuff...
		#local HoldVec = <0.0025, 0.005, 0>;
		#local RoofBorder =  x * 0.15;
		#local RoofSlope = <-0.15, 0.1, 0>;
		
		// Wire holders
		union
		{
			cylinder
			{
				0,
				HoldVec, 0.001
			}
			sphere
			{
				HoldVec, 0.002
			}
			translate RoofBorder + RoofSlope * (1/4)
		}
		union
		{
			cylinder
			{
				0,
				HoldVec, 0.001
			}
			sphere
			{
				HoldVec, 0.002
			}
			translate RoofBorder + RoofSlope * (3/4)
		}
		
		// The wire itself...
		sphere_sweep
		{
			cubic_spline, 10
			<0.155, 0, 0>, 0.001
			RoofBorder + HoldVec + RoofSlope * 0, 0.001
			RoofBorder + HoldVec * 1.10 + RoofSlope * (1/8), 0.001
			RoofBorder + HoldVec + RoofSlope * (1/4), 0.001
			RoofBorder + HoldVec * 0.8 + RoofSlope * (1/2), 0.001
			RoofBorder + HoldVec + RoofSlope * (3/4), 0.001
			RoofBorder + HoldVec * 0.82 + RoofSlope * 0.84, 0.001
			<0.014, 0.0955, 0>, 0.001
			<0.009, 0.097, 0>, 0.001
			<0.009, 0.097, 0>, 0.001
		}
	}
	texture {MyBlack}
}

#declare LighthouseTop = union
{
	object
	{
		Lamphouse
		// Adjust "windows"
		rotate y * 16
	}
	object {LampStuff}
	object
	{
		Roof
		translate y * 0.2
		// Match "windows" rotation
		rotate y * 16
	}
}
